;*****************************************************************************
;  Calculate the radiance corrected for RSR.
;
;  Inputs:
;  1) rsrf -- RSR data.
;  2) T -- temperature.
;  3) band -- band index.
;  4) numdet -- number of detectors.
;
;  Outputs:
;  1) l_avg -- Result of integral.
;
;  v1 - Chunhui Pan
;  v2 - 5/29/2008 - Jeff McIntire
;*****************************************************************************

FUNCTION get_avg_2, rsrf,T,band,ndet

; Reform rsr and find out how many non zero entries per detector.
rsr_temp=reform(rsrf[band,2,*])
ix=WHERE(rsr_temp NE 0,count)
iy=count/ndet 
IF count LE 0 THEN print,'Check rsr file =>',rsrf

; Get rid of zeros.
rsr=dblarr(8,3,count)
i=0
idet=0
FOR j=0, 40*ndet-1 DO BEGIN
    IF i EQ 40 THEN BEGIN
        i=0
        idet=idet+1
    ENDIF
    IF i LT iy THEN BEGIN
        rsr[band,*,idet*iy+i]=rsrf[band,*,j]
    ENDIF
    i=i+1
ENDFOR

radiance=fltarr(8,ndet*iy)
temp1=fltarr(ndet)
temp2=fltarr(ndet)
l_avg=fltarr(ndet)

; Get the Planck radiances.
FOR b=0, 7 DO BEGIN
    FOR j=0, ndet*iy-1 DO BEGIN
        radiance[b,j]=Planck(T,rsr[b,1,j])
    ENDFOR
ENDFOR

FOR idet=0, ndet-1 DO BEGIN
    ; If an even number of node points, drop the last point.
    IF 2*fix(iy/2)-iy EQ 0 THEN BEGIN
        FOR j=idet*iy+1, idet*iy+iy-5, 2 DO BEGIN
            temp1[idet]=temp1[idet]+4.*radiance[band,j]*rsr[band,2,j]+2.*radiance[band,j+1]*rsr[band,2,j+1]
            temp2[idet]=temp2[idet]+4.*rsr[band,2,j]+2.*rsr[band,2,j+1]
        ENDFOR
        l_avg[idet]=(radiance[band,idet*iy]*rsr[band,2,idet*iy]+temp1[idet] $
                     +4.*radiance[band,idet*iy+iy-3]*rsr[band,2,idet*iy+iy-3] $
                     +radiance[band,idet*iy+iy-2]*rsr[band,2,idet*iy+iy-2]) $
          /(rsr[band,2,idet*iy]+temp2[idet]+4.*rsr[band,2,idet*iy+iy-3]+rsr[band,2,idet*iy+iy-2])
    ENDIF ELSE BEGIN
        FOR j=idet*iy+1, idet*iy+iy-4, 2 DO BEGIN
            temp1[idet]=temp1[idet]+4.*radiance[band,j]*rsr[band,2,j]+2.*radiance[band,j+1]*rsr[band,2,j+1]
            temp2[idet]=temp2[idet]+4.*rsr[band,2,j]+2.*rsr[band,2,j+1]
        ENDFOR
        l_avg[idet]=(radiance[band,idet*iy]*rsr[band,2,idet*iy]+temp1[idet] $
                     +4.*radiance[band,idet*iy+iy-2]*rsr[band,2,idet*iy+iy-2] $
                     +radiance[band,idet*iy+iy-1]*rsr[band,2,idet*iy+iy-1]) $
          /(rsr[band,2,idet*iy]+temp2[idet]+4.*rsr[band,2,idet*iy+iy-2]+rsr[band,2,idet*iy+iy-1])
    ENDELSE
ENDFOR

RETURN,l_avg

END
