;*****************************************************************************
;  Function which returns the average of an array or the standard deviation
;  with a n_sigma kick out.
;
;  Inputs:
;  1) in_array   -- array to be averaged.
;  2) n_sigma -- # of standard deviations included.
;  3) flag    -- 1 to return the average or 2 to return the standard deviation.
;  
;  v1 - 08/16/2006 - Chunhui Pan
;  v2 - 11/26/2007 - Jeff McIntire
;  v3 - 05/13/2009 - Jeff McIntire
;     - Fixed problem of zeros sometimes being included in averages.
;*****************************************************************************

FUNCTION sig_mean, in_array,n_sigma,flag

y=WHERE(in_array,count)
IF count EQ 0 THEN return,-999
IF count EQ 1 THEN BEGIN
	mu=in_array[y]
	std=0.0
	goto,skip
ENDIF

avg=mean(in_array[y])
std=stddev(in_array[y])

sig=double(n_sigma*std)
 
x=WHERE(abs(in_array(*)-avg) LE sig AND in_array(*) NE 0,cnt)
IF cnt LE 0 THEN BEGIN
	mu=0.0
	std=0.0
ENDIF
IF cnt EQ 1 THEN BEGIN
	mu=avg
	std=0.0
ENDIF
IF cnt GT 1 THEN BEGIN
	mu=mean(in_array(x))
	std=stddev(in_array(x))
ENDIF

skip:
IF flag EQ 1 THEN return,mu
IF flag EQ 2 THEN return,std 

END
